package com.goldenwater.slaj.ttsa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.ttsa.mapper.BisTtsaTrainPersMapper;
import com.goldenwater.slaj.ttsa.domain.BisTtsaTrainPers;
import com.goldenwater.slaj.ttsa.service.IBisTtsaTrainPersService;

@Service
public class BisTtsaTrainPersServiceImpl implements IBisTtsaTrainPersService {
    @Autowired
    private BisTtsaTrainPersMapper bisTtsaTrainPersMapper;

    @Override
    public BisTtsaTrainPers selectBisTtsaTrainPersByGuid(String guid) {
        return bisTtsaTrainPersMapper.selectBisTtsaTrainPersByGuid(guid);
    }

    @Override
    public List<BisTtsaTrainPers> selectBisTtsaTrainPersList(BisTtsaTrainPers bisTtsaTrainPers) {
        return bisTtsaTrainPersMapper.selectBisTtsaTrainPersList(bisTtsaTrainPers);
    }

    @Override
    public int insertBisTtsaTrainPers(BisTtsaTrainPers bisTtsaTrainPers) {
        return bisTtsaTrainPersMapper.insertBisTtsaTrainPers(bisTtsaTrainPers);
    }

    @Override
    public int updateBisTtsaTrainPers(BisTtsaTrainPers bisTtsaTrainPers) {
        return bisTtsaTrainPersMapper.updateBisTtsaTrainPers(bisTtsaTrainPers);
    }

    @Override
    public int deleteBisTtsaTrainPersByGuid(String guid) {
        return bisTtsaTrainPersMapper.deleteBisTtsaTrainPersByGuid(guid);
    }

    @Override
    public int deleteBisTtsaTrainPersByGuids(String[] guids) {
        return bisTtsaTrainPersMapper.deleteBisTtsaTrainPersByGuids(guids);
    }
}
